@@ -163,8 +163,10 @@ class Bootstrap:
             # XXX console.print("No machines found")
             versions = web.host.Machine.versions
             start_time = time.time()
-            total_time = 13
-            with console.status(f"[bold green]{total_time} min remaining") as status:
+            total_time = 15
+            with console.status(
+                f"[bold green]around {total_time} minutes remaining"
+            ) as status:
 
                 def update_status():
                     while True:
@@ -174,7 +176,9 @@ class Bootstrap:
                         if remaining_time < 1:
                             status.update("Finishing up..")
                             return
-                        status.update(f"[bold green]{remaining_time} minutes remaining")
+                        status.update(
+                            f"[bold green]around {remaining_time} minutes remaining"
+                        )
                         gevent.sleep(1)
 
                 gevent.spawn(update_status)
