@@ -441,6 +441,13 @@ class Machine(MachineBase):
                 "stopsignal": "INT",
                 "user": "gaea",
             }
+            config["program:queue"] = {
+                "autostart": "true",
+                "command": f"{self.runinenv} {env_dir} bgq run",
+                "directory": run_dir,
+                "stopsignal": "INT",
+                "user": "gaea",
+            }
 
     # def install_project(self, registrar, project_root=Path(".")):
     #     """Install sites from project in `project_root`."""
